@@ -12,18 +12,23 @@
 #ifndef LIBC_MUSL
 # define LIBC_MUSL 4
 #endif
+#ifndef HEAP_TRAMPOLINES_INIT
+# define HEAP_TRAMPOLINES_INIT 0
+#endif
 #ifndef TARGET_ENABLE_BTI
 # define TARGET_ENABLE_BTI 1
 #endif
 #ifndef TARGET_ENABLE_PAC_RET
 # define TARGET_ENABLE_PAC_RET 1
 #endif
+#ifndef TARGET_ENABLE_GCS
+# define TARGET_ENABLE_GCS 1
+#endif
 #ifdef IN_GCC
 # include "options.h"
 # include "insn-constants.h"
 # include "config/aarch64/biarchlp64.h"
 # include "config/aarch64/aarch64.h"
-# include "config/dbxelf.h"
 # include "config/elfos.h"
 # include "config/aarch64/aarch64-elf.h"
 # include "config/openbsd-stdint.h"
