@@ -12,9 +12,15 @@
 #ifndef LIBC_MUSL
 # define LIBC_MUSL 4
 #endif
+#ifndef HEAP_TRAMPOLINES_INIT
+# define HEAP_TRAMPOLINES_INIT 0
+#endif
 #ifndef DEFAULT_FLAG_PIE
 # define DEFAULT_FLAG_PIE 1
 #endif
+#ifndef USE_IX86_FRAME_POINTER
+# define USE_IX86_FRAME_POINTER 1
+#endif
 #ifdef IN_GCC
 # include "options.h"
 # include "insn-constants.h"
@@ -22,7 +28,6 @@
 # include "config/i386/i386.h"
 # include "config/i386/unix.h"
 # include "config/i386/att.h"
-# include "config/dbxelf.h"
 # include "config/elfos.h"
 # include "config/openbsd.h"
 # include "config/openbsd-stdint.h"
