@@ -1,6 +1,21 @@
 #ifndef GCC_TM_H
 #define GCC_TM_H
-#define TARGET_CPU_DEFAULT ((MASK_SPLIT_ADDRESSES)|MASK_EXPLICIT_RELOCS)
+#define TARGET_CPU_DEFAULT (MASK_SPLIT_ADDRESSES)
+#ifndef LIBC_GLIBC
+# define LIBC_GLIBC 1
+#endif
+#ifndef LIBC_UCLIBC
+# define LIBC_UCLIBC 2
+#endif
+#ifndef LIBC_BIONIC
+# define LIBC_BIONIC 3
+#endif
+#ifndef LIBC_MUSL
+# define LIBC_MUSL 4
+#endif
+#ifndef HEAP_TRAMPOLINES_INIT
+# define HEAP_TRAMPOLINES_INIT 0
+#endif
 #ifndef MIPS_ISA_DEFAULT
 # define MIPS_ISA_DEFAULT 3
 #endif
@@ -14,7 +29,6 @@
 # include "options.h"
 # include "insn-constants.h"
 # include "config/vxworks-dummy.h"
-# include "config/dbxelf.h"
 # include "config/elfos.h"
 # include "config/openbsd.h"
 # include "config/openbsd-stdint.h"
