@@ -12,6 +12,9 @@
 #ifndef LIBC_MUSL
 # define LIBC_MUSL 4
 #endif
+#ifndef HEAP_TRAMPOLINES_INIT
+# define HEAP_TRAMPOLINES_INIT 0
+#endif
 #ifndef DEFAULT_FLAG_PIE
 # define DEFAULT_FLAG_PIE 2
 #endif
@@ -21,7 +24,6 @@
 # include "config/vxworks-dummy.h"
 # include "config/rs6000/secureplt.h"
 # include "config/rs6000/rs6000.h"
-# include "config/dbxelf.h"
 # include "config/elfos.h"
 # include "config/gnu-user.h"
 # include "config/openbsd.h"
