@@ -12,23 +12,28 @@
 #ifndef LIBC_MUSL
 # define LIBC_MUSL 4
 #endif
+#ifndef HEAP_TRAMPOLINES_INIT
+# define HEAP_TRAMPOLINES_INIT 0
+#endif
 #ifndef TARGET_DEFAULT_ISA_SPEC
-# define TARGET_DEFAULT_ISA_SPEC ISA_SPEC_CLASS_2P2
+# define TARGET_DEFAULT_ISA_SPEC ISA_SPEC_CLASS_20191213
 #endif
 #ifndef TARGET_RISCV_ATTRIBUTE
-# define TARGET_RISCV_ATTRIBUTE 0
+# define TARGET_RISCV_ATTRIBUTE 1
 #endif
 #ifndef TARGET_RISCV_DEFAULT_ARCH
-# define TARGET_RISCV_DEFAULT_ARCH rv64imafdc
+# define TARGET_RISCV_DEFAULT_ARCH rv64imafdc_zicsr_zifencei_zaamo_zalrsc
 #endif
 #ifndef TARGET_RISCV_DEFAULT_ABI
 # define TARGET_RISCV_DEFAULT_ABI lp64d
 #endif
+#ifndef TARGET_DEFAULT_CMODEL
+# define TARGET_DEFAULT_CMODEL CM_MEDLOW
+#endif
 #ifdef IN_GCC
 # include "options.h"
 # include "insn-constants.h"
 # include "config/riscv/riscv.h"
-# include "config/dbxelf.h"
 # include "config/elfos.h"
 # include "config/openbsd-stdint.h"
 # include "config/openbsd.h"
