@@ -13,6 +13,9 @@
 #ifndef LIBC_MUSL
 # define LIBC_MUSL 4
 #endif
+#ifndef HEAP_TRAMPOLINES_INIT
+# define HEAP_TRAMPOLINES_INIT 0
+#endif
 #ifndef DEFAULT_FLAG_PIE
 # define DEFAULT_FLAG_PIE 2
 #endif
@@ -22,7 +25,6 @@
 # include "config/vxworks-dummy.h"
 # include "config/sparc/openbsd1-64.h"
 # include "config/sparc/sparc.h"
-# include "config/dbxelf.h"
 # include "config/elfos.h"
 # include "config/sparc/sysv4.h"
 # include "config/sparc/sp64-elf.h"
